//this file describes the 3 parts for the entire kinematic mount
//comment out the individual parts in the bottom of the file

//the laser beam is 18.4mm above the spectrometer floor 
//so the microscopeobjective should have its center at
//this height
beam_z = 18.4;

//misc
M3 = 1.65;
M2 = 0.9;
cf = 48;

//base height
bh = 2.5;

//dimensions of the dichroic mirror (18x26x1mm)
dmirx = 26+0.5;
dmiry = 1+0.25;
dmirz = 18+0.5;

mx = 8;
my = 2;
mz = 8;

dedgx = dmirx + mx + 7;
dedgz = dmirz + mz + 7;

odedgx = dmirx + mx + 7 + 12;
odedgz = dmirz + mz + 7 + 12;

dox = 47.5;
doz = 41.65;

zref = doz/2 - 6;

DICp1 = [-dmirx/2,dmiry/2+2];
DICp2 = [dmirx/2+5.25,dmiry/2+2];
DICp3 = [dmirx/2,-dmiry/2-2];
DICp4 = [-dmirx/2-5.25,-dmiry/2-2];



//module DICmirror(){
//	difference(){
//		translate([0,0,-beam_z/2+1]){
//			linear_extrude(height=beam_z+2, center=true, convexity = 10)
//			polygon(points = [DICp1,DICp2,DICp3,DICp4], convexity = 10);}
//		cube(size=[dmirx,dmiry,dmirz],center=true);
//		cube(size=[dmirx-2,10,dmirz-2],center=true);

//		rotate([0,0,45]) cube(size=[dmirx-10,50,dmirz-2],center=true);
//	}
//}

module DICmirrorsw(){
	difference(){
		cube(size=[dmirx+mx,dmirz+mz,dmir_y+my], center=true);

		cube(size=[dmirx-2,dmirz-2,dmiry], center=true);
		translate([0,0,0.5]) cube(size=[dmirx,dmirz,dmiry-0.5], center=true);

		translate([(dmirx+3)/2,(dmirz+3)/2,0]) cylinder(r=1, h=5, $fn=cf,center=true);
		translate([-(dmirx+3)/2,-(dmirz+3)/2,0]) cylinder(r=1, h=5, $fn=cf,center=true);
		translate([(dmirx+3)/2,-(dmirz+3)/2,0]) cylinder(r=1, h=5, $fn=cf,center=true);
		translate([-(dmirx+3)/2,(dmirz+3)/2,0]) cylinder(r=1, h=5, $fn=cf,center=true);
		//translate([(dmirx+4)/2,(dmirz+4)/2,0]) cylinder(r=1, h=5, $fn=cf,center=true);
	}
}


module DICmirrorkm(){
	difference(){
		cube(size=[dmirx+mx,dmirz+mz,bh], center=true);

		translate([0,0,bh/2]) cube(size=[dmirx,dmirz,dmiry], center=true);
		cube(size=[dmirx-2,dmirz-2,5], center=true);

		translate([(dmirx+3)/2,(dmirz+3)/2,0]) cylinder(r=M2, h=5, $fn=cf,center=true);
		translate([(dmirx+3)/2,-(dmirz+3)/2,0]) cylinder(r=M2, h=5, $fn=cf,center=true);
		translate([-(dmirx+3)/2,(dmirz+3)/2,0]) cylinder(r=M2, h=5, $fn=cf,center=true);
		translate([-(dmirx+3)/2,-(dmirz+3)/2,0]) cylinder(r=M2, h=5, $fn=cf,center=true);
	}
}


module DICmirrorbase(){
	translate([0,beam_z,0]) DICmirrorkm();
//	translate([0,3.5,(4-bh)/2]) cube(size=[10,8,4], center=true);

	translate([3.5,beam_z-7/2,(4-bh)/2]){
		difference(){
			cube(size=[dedgx,dedgz,4],center=true);

			translate([-6,6,0]) cube(size=[dedgx,dedgz,8],center=true);

			translate([0, -dedgz/2+3,0]){
				cylinder(r=M3, $fn=24, h=10, center=true);
				translate([0,0,-2]){
					rotate([0,90,0]) cylinder(r=0.5, h=8, $fn=6, center=true);}
			}
			translate([dedgx/2-3,0,0]){
				cylinder(r=M3, $fn=24, h=10, center=true);
				translate([0,0,-2]){
					rotate([90,30,0]) cylinder(r=0.5, h=8, $fn=6, center=true);}
			}

			translate([dedgx/2-3,-dedgz/2+3,-1]) cylinder(r1=0, r2=M3, $fn=24, h=3);
			translate([dedgx/2-3,dedgz/2-3,-1]) cylinder(r1=0, r2=M3, $fn=24, h=3);
			translate([-dedgx/2+3,-dedgz/2+3,-1]) cylinder(r1=0, r2=M3, $fn=24, h=3);
		}
	}

	translate([3.5,5,0]) cube(size=[dedgx,2,bh], center=true);
	translate([(dmirx+mx)/2,beam_z-7/2,0]){
		cube(size=[2,dedgz,bh], center=true);}

}



module DIC_kmbase(){
	difference(){
		union(){
			cube(size=[dox,doz,6], center=true);
			translate([-dox/2+6,zref,0]) cylinder(r=4, $fn=cf, h=5);	
		}
	
		translate([12,-12,0]) cube(size=[dox,doz,7], center=true);

		//springs
		translate([0,zref,0]){ 
				cylinder(r=M3+0.2, $fn=24, h=10, center=true);
				translate([0,0,-3]){
					rotate([90,30,0]) cylinder(r=0.5, h=8, $fn=6, center=true);}
			}

		translate([-dox/2+6,zref-13.75,0]){
				cylinder(r=M3+0.2, $fn=24, h=10, center=true);
				translate([0,0,-3]){
					rotate([0,90,0]) cylinder(r=0.5, h=8, $fn=6, center=true);}	
		}

		//ball bearing
		translate([-dox/2+6,zref,2]){ 
			cylinder(r1=0, r2=M3, $fn=24, h=3);
		}


		//M3's

		translate([dox/2-6,zref,-1.75]){
			cylinder(r=M3, h=10, $fn=cf, center=true);
			cylinder(r=3.2, h=4, $fn=6);
			translate([0,0,2]) cylinder(r=4, h=4, $fn=cf);
		}

		translate([-dox/2+6,zref-2*13.75,-2]){
			cylinder(r=M3, h=10, $fn=cf, center=true);
			rotate([0,0,30]) cylinder(r=3.2, h=4, $fn=6);
			translate([0,0,2]) cylinder(r=4, h=4, $fn=cf);
		}


	}
}




DICmirrorsw();

//mirror([0,0,0]) DICmirrorbase();	

//mirror([1,0,0]) DIC_kmbase();
/*translate([dox/2-0.1,-doz/2,-3]) difference(){
		cube(size=[15,20,4]);

		translate([5,5,2]){
			cylinder(r=M3, h=10, $fn=48, center=true);
			cylinder(r=3.2, h=3, $fn=6);}
		translate([10,15,2]){
			cylinder(r=M3, h=10, $fn=48, center=true);
			cylinder(r=3.2, h=3, $fn=6);}
	
	
}*/

